@@ -36,7 +36,7 @@ class ForamAggregateAgent(Addressable):
 
 class Foram(Addressable):
     @Inject("genom_factory", "reproduction_minimum", "movement_energy", "growth_minimum", "energy_need",
-            "newborn_limit")
+            "newborn_limit", "reproduction_probability", "growth_probability", "growth_cost_factor", "capacity_factor")
     def __init__(self, energy, genom=None):
         super(Foram, self).__init__()
         self.energy = energy
@@ -45,7 +45,7 @@ class Foram(Addressable):
         else:
             self.genom = genom
         self.steps = 0
-        self.chambers = 0
+        self.chambers = 1
         self.alive = True
         self.cell = None
 
@@ -71,7 +71,7 @@ class Foram(Addressable):
         return self.energy - e
 
     def _energy_capacity(self):
-        capacity = self.chambers + 1
+        capacity = self.chambers * self.capacity_factor
         return capacity
 
     def _energy_demand(self):
@@ -89,7 +89,8 @@ class Foram(Addressable):
         return taken
 
     def _can_reproduce(self):
-        return self.energy > self.reproduction_minimum and self.genom.chambers_limit <= self.chambers
+        return self.energy > self.reproduction_minimum and self.genom.chambers_limit <= self.chambers \
+            and random() < self.reproduction_probability
 
     @counted
     def _reproduce(self):
@@ -102,11 +103,12 @@ class Foram(Addressable):
             empty_neighbours = sample(empty_neighbours, self.newborn_limit)
         energy = self.energy / (len(empty_neighbours) * 2.0)
         for cell in empty_neighbours:
-            self.energy -= energy
+            self.energy = 0
             foram = Foram(energy, Genom(self.genom.chambers_limit))
             cell.insert_foram(foram)
             self.parent.add_foram(foram)
-        logger.debug("%s has reproduced into %d cells" % ( self, len(empty_neighbours)))
+        logger.debug("%s has reproduced into %d cells and will now die" % (self, len(empty_neighbours)))
+        self._die()
 
     def _move(self):
         try:
@@ -134,10 +136,11 @@ class Foram(Addressable):
         self.cell.remove_foram()
 
     def _can_create_chamber(self):
-        return self.energy > self.growth_minimum and self.genom.chambers_limit > self.chambers
+        return self.energy > self.growth_minimum and self.genom.chambers_limit > self.chambers \
+            and random() > self.growth_probability
 
     def _create_chamber(self):
-        self.energy -= 5
+        self.energy -= self.growth_cost_factor * self.energy
         self.chambers += 1
         logger.debug("Foram %s has a new chamber, so %d altogether" % (self, self.chambers))
 
